@@ -19,11 +19,9 @@ class LinkUtils:
 
     @staticmethod
     def find(wait: WebDriverWait, label: str):
-        xpath = f'.//a[normalize-space(text())="{label}"]'
+        xpath = f'.//a[normalize-space(.)="{label}"]'
         try:
             component = wait.until(EC.element_to_be_clickable((By.XPATH, xpath)))
-        except TimeoutError as e:
-            raise TimeoutError(f"Could not find clickable link with label '{label}': {e}")
         except Exception as e:
             raise Exception(f"Could not find clickable link with label '{label}': {e}")
         return component
